@@ -18,5 +18,10 @@ ext_i_frames_only = '#EXT-X-I-FRAMES-ONLY'
 ext_x_byterange = '#EXT-X-BYTERANGE'
 ext_x_i_frame_stream_inf = '#EXT-X-I-FRAME-STREAM-INF'
 ext_x_discontinuity = '#EXT-X-DISCONTINUITY'
+ext_x_cue_out_start = '#EXT-X-CUE-OUT'
 ext_x_cue_out = '#EXT-X-CUE-OUT-CONT'
 ext_is_independent_segments = '#EXT-X-INDEPENDENT-SEGMENTS'
+ext_x_scte35 = '#EXT-OATCLS-SCTE35'
+ext_x_cue_start = '#EXT-X-CUE-OUT'
+ext_x_cue_end = '#EXT-X-CUE-IN'
+ext_x_cue_span = '#EXT-X-CUE-SPAN'
